@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -17,6 +17,4 @@ EmoticonListView::EmoticonListView(QWidget *parent)
     });
 }
 
-EmoticonListView::~EmoticonListView()
-{
-}
+EmoticonListView::~EmoticonListView() = default;
