@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -19,7 +19,10 @@
 #include <QIcon>
 
 #ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
-#include "texttospeech/texttospeech.h"
+#include <KPIMTextEditTextToSpeech/TextToSpeech>
+#endif
+#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+#include <TextEditTextToSpeech/TextToSpeech>
 #endif
 #include <Sonnet/Dialog>
 #include <sonnet/backgroundchecker.h>
@@ -138,12 +141,20 @@ void PlainTextEditor::contextMenuEvent(QContextMenuEvent *event)
         if (d->supportFeatures & Search) {
             popup->addSeparator();
             if (!emptyDocument) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
                 popup->addAction(KStandardGuiItem::find().icon(), KStandardGuiItem::find().text(), this, &PlainTextEditor::findText, Qt::Key_F | Qt::CTRL);
+#else
+                popup->addAction(KStandardGuiItem::find().icon(), KStandardGuiItem::find().text(), Qt::Key_F | Qt::CTRL, this, &PlainTextEditor::findText);
+#endif
                 popup->addSeparator();
             }
             if (!isReadOnly()) {
                 if (!emptyDocument) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
                     popup->addAction(i18n("Replace..."), this, &PlainTextEditor::replaceText, Qt::Key_R | Qt::CTRL);
+#else
+                    popup->addAction(i18n("Replace..."), Qt::Key_R | Qt::CTRL, this, &PlainTextEditor::replaceText);
+#endif
                     popup->addSeparator();
                 }
             }
@@ -196,12 +207,17 @@ void PlainTextEditor::contextMenuEvent(QContextMenuEvent *event)
         }
         if (d->supportFeatures & TextToSpeech) {
 #ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
-            if (KPIMTextEdit::TextToSpeech::self()->isReady()) {
-                if (!emptyDocument) {
-                    QAction *speakAction = popup->addAction(i18n("Speak Text"));
-                    speakAction->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-text-to-speech")));
-                    connect(speakAction, &QAction::triggered, this, &PlainTextEditor::slotSpeakText);
-                }
+            if (!emptyDocument) {
+                QAction *speakAction = popup->addAction(i18n("Speak Text"));
+                speakAction->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-text-to-speech")));
+                connect(speakAction, &QAction::triggered, this, &PlainTextEditor::slotSpeakText);
+            }
+#endif
+#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+            if (!emptyDocument) {
+                QAction *speakAction = popup->addAction(i18n("Speak Text"));
+                speakAction->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-text-to-speech")));
+                connect(speakAction, &QAction::triggered, this, &PlainTextEditor::slotSpeakText);
             }
 #endif
         }
