@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -9,7 +9,10 @@
 #include "plaintexteditor.h"
 #include "slidecontainer.h"
 #ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
-#include "texttospeech/texttospeechwidget.h"
+#include <KPIMTextEditTextToSpeech/TextToSpeechContainerWidget>
+#endif
+#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+#include <TextEditTextToSpeech/TextToSpeechContainerWidget>
 #endif
 #include <QTextCursor>
 #include <QVBoxLayout>
@@ -23,7 +26,10 @@ public:
     KPIMTextEdit::PlainTextEditFindBar *mFindBar = nullptr;
     PlainTextEditor *mEditor = nullptr;
 #ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
-    KPIMTextEdit::TextToSpeechWidget *mTextToSpeechWidget = nullptr;
+    KPIMTextEditTextToSpeech::TextToSpeechContainerWidget *mTextToSpeechWidget = nullptr;
+#endif
+#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+    TextEditTextToSpeech::TextToSpeechContainerWidget *mTextToSpeechWidget = nullptr;
 #endif
     KPIMTextEdit::SlideContainer *mSliderContainer = nullptr;
 };
@@ -79,7 +85,11 @@ void PlainTextEditorWidget::init(PlainTextEditor *customEditor)
     auto lay = new QVBoxLayout(this);
     lay->setContentsMargins({});
 #ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
-    d->mTextToSpeechWidget = new KPIMTextEdit::TextToSpeechWidget(this);
+    d->mTextToSpeechWidget = new KPIMTextEditTextToSpeech::TextToSpeechContainerWidget(this);
+    lay->addWidget(d->mTextToSpeechWidget);
+#endif
+#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+    d->mTextToSpeechWidget = new TextEditTextToSpeech::TextToSpeechContainerWidget(this);
     lay->addWidget(d->mTextToSpeechWidget);
 #endif
     if (customEditor) {
@@ -89,7 +99,10 @@ void PlainTextEditorWidget::init(PlainTextEditor *customEditor)
     }
     lay->addWidget(d->mEditor);
 #ifdef HAVE_TEXT_TO_SPEECH_SUPPORT
-    connect(d->mEditor, &PlainTextEditor::say, d->mTextToSpeechWidget, &KPIMTextEdit::TextToSpeechWidget::say);
+    connect(d->mEditor, &PlainTextEditor::say, d->mTextToSpeechWidget, &KPIMTextEditTextToSpeech::TextToSpeechContainerWidget::say);
+#endif
+#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+    connect(d->mEditor, &PlainTextEditor::say, d->mTextToSpeechWidget, &TextEditTextToSpeech::TextToSpeechContainerWidget::say);
 #endif
     d->mSliderContainer = new KPIMTextEdit::SlideContainer(this);
 
