@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  */
@@ -8,7 +8,7 @@
 
 #include "kpimtextedit_export.h"
 #include <QObject>
-
+#include <memory>
 class QCompleter;
 class QTextEdit;
 class QPlainTextEdit;
@@ -38,7 +38,6 @@ public:
 private:
     void slotCompletion(const QString &text);
     class TextEditorCompleterPrivate;
-    TextEditorCompleterPrivate *const d;
+    std::unique_ptr<TextEditorCompleterPrivate> const d;
 };
 }
-
